package com.chinaitop.depot.tasks;

import com.chinaitop.depot.intelligent.feign.CommandInterface;
import com.chinaitop.depot.intelligent.monitor.MonitorInterface;
import com.chinaitop.depot.intelligent.warningAndAlarm.WarningAndAlarmInterface;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 定义任务实现类
 * @create 2024-05-14 11:20
 */
@Slf4j
@Component
public class TaskRunning {
    @Resource
    private CommandInterface commandInterface;
    @Resource
    private MonitorInterface monitorInterface;
    @Resource
    private WarningAndAlarmInterface warningAndAlarmInterface;

    /**
     * spring的@Scheduled只支持6位，年份是不支持的，带年份的7位格式会报错：
     * Cron expression must consist of 6 fields (found 7 in "1/5 * * * * ? 2018")
     *
     * @Scheduled 注解表示当前方法就是一个任务调度执行对象
     * 通过cron表达式 来配置 该方法的执行周期
     **/


    //  5秒 直接在方法上使用注解即可完成扫描
//    @Scheduled(cron = "0 */1 * * * ?")
//    public void run() {
//        Map<String, Object> map = new HashMap<>();
//        map.put("storehouseCode", "");
//        map.put("ilqYq", "0");
//        map.put("orgId", "");
//        commandInterface.sendStoreDetection(map);
//        log.info("----每天5秒执行---");
//    }

    @Scheduled(cron = "0 0 10 * * ?") //  每天上午10点执行
    public void tempRun() {
        Map<String, Object> map = new HashMap<>();
        map.put("storehouseCode", "");
        map.put("ilqYq", "0");
        map.put("orgId", "");
        commandInterface.sendStoreDetection(map);
        log.info("----每天上午10点执行---");
    }

    @Scheduled(cron = "0 */10 * * * *")
    public void monitorRun() {

        monitorInterface.updateMonitorStatus();
        log.info("----10分钟执行---");
    }

    @Scheduled(cron = "0 0 1 * * ?") //  每天凌晨1点执行
    public void warningAndAlarmYlwlRun() {

        warningAndAlarmInterface.checkYlwl();
        log.info("----每天凌晨1点执行---");
    }

    @Scheduled(cron = "0 30 1 * * ?") //  每天凌晨1:30点执行
    public void warningAndAlarmLhyjRun() {

        warningAndAlarmInterface.checkLhyj();
        log.info("----每天凌晨1:30点执行---");
    }

    @Scheduled(cron = "0 0 2 * * ?") //  每天凌晨2点执行
    public void warningAndAlarmJkqyjRun() {

        warningAndAlarmInterface.checkJkqyj();
        log.info("----每天凌晨2点执行---");
    }






}
